summaryrefslogtreecommitdiffstats
path: root/arch/blackfin/cpu-bf561/start.S
diff options
context:
space:
mode:
authorSascha Hauer <s.hauer@pengutronix.de>2009-12-15 09:11:09 +0100
committerSascha Hauer <s.hauer@pengutronix.de>2009-12-15 10:18:30 +0100
commita3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97 (patch)
tree7a9076c1a20df00baeadca9a07d4c1f5cd0611e2 /arch/blackfin/cpu-bf561/start.S
parentcaa5cec7b1c93d660aa89d24eb160ab18e4eb628 (diff)
downloadbarebox-a3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97.tar.gz
barebox-a3ffa97f40dc81f2d6b07ee964f2340fe0c1ba97.tar.xz
rename U-Boot-v2 project to barebox
This has been done with the following script: find -path ./.git -prune -o -type f -print0 | xargs -0 -r sed -i \ -e 's/u2boot/barebox/g' \ -e 's/U2Boot/barebox/g' \ -e 's/U-boot V2/barebox/g' \ -e 's/u-boot v2/barebox/g' \ -e 's/U-Boot V2/barebox/g' \ -e 's/U-Boot-v2/barebox/g' \ -e 's/U_BOOT/BAREBOX/g' \ -e 's/UBOOT/BAREBOX/g' \ -e 's/uboot/barebox/g' \ -e 's/u-boot/barebox/g' \ -e 's/u_boot/barebox/g' \ -e 's/U-Boot/barebox/g' \ -e 's/U-boot/barebox/g' \ -e 's/U-BOOT/barebox/g' find -path ./.git -prune -o \( -name "*u-boot*" -o -name "*uboot*" -o -name "*u_boot*" \) -print0 | \ xargs -0 -r rename 's/u[-_]?boot/barebox/' It needs some manual fixup following in the next patch Signed-off-by: Sascha Hauer <s.hauer@pengutronix.de>
Diffstat (limited to 'arch/blackfin/cpu-bf561/start.S')
-rw-r--r--arch/blackfin/cpu-bf561/start.S6
1 files changed, 3 insertions, 3 deletions
diff --git a/arch/blackfin/cpu-bf561/start.S b/arch/blackfin/cpu-bf561/start.S
index 81efff09b6..434536248c 100644
--- a/arch/blackfin/cpu-bf561/start.S
+++ b/arch/blackfin/cpu-bf561/start.S
@@ -1,5 +1,5 @@
/*
* U-boot - start.S Startup file of u-boot for BF533/BF561
*
* Copyright (c) 2005 blackfin.uclinux.org
*
@@ -333,8 +333,8 @@ _clear_bss_skip:
[p0] = r0;
#endif
- p0.l = _start_uboot;
- p0.h = _start_uboot;
+ p0.l = _start_barebox;
+ p0.h = _start_barebox;
jump (p0);
reset_start:
@@ -1,5 +1,5 @@
/*
- * U-boot - start.S Startup file of u-boot for BF533/BF561
+ * barebox - start.S Startup file of barebox for BF533/BF561
*
* Copyright (c) 2005 blackfin.uclinux.org